VersionarteStatus enum

Enum representing the versioning status of the app for the current platform.

Inheritance
Available extensions

Values

upToDate → const VersionarteStatus

The user has the latest version of the app.

outdated → const VersionarteStatus

There is a new version available, but it is not mandatory to update.

forcedUpdate → const VersionarteStatus

There is a new version available and the user must update to continue using the app.

inactive → const VersionarteStatus

The app is not currently available, for example due to maintenance.

unknown → const VersionarteStatus

An error occurred while checking.

The message property of the VersionarteResult object can be checked to see the possible error that caused this status.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VersionarteStatus>
A constant List of the values in this enum, in order of their declaration.