versionarte library
Classes
- DistributionManifest
- A serverside representation model of the app versioning.
- PlatformDistributionInfo
- RemoteConfigVersionarteProvider
-
A VersionarteProvider that retrieves DistributionManifest information stored in Firebase
Remote Config using the key name "versionarte" or a different key name specified through
the
keyNameconstructor parameter. - RestfulVersionarteProvider
- A VersionarteProvider that helps retrieve DistributionManifest information via sending an HTTP GET request with the given headers to the given URL.
- StatusDetails
- Represents the status of an application.
- Versionarte
- Checks the version of the app on the device against the version on the store.
- VersionarteProvider
- An interface for a server-side store versioning information provider.
- VersionarteResult
- Result of a version check
- VersionDetails
- Represents the minimum and latest versions of an application.
Enums
- VersionarteStatus
- Enum representing the versioning status of the app for the current platform.